@@ -24,10 +24,11 @@ class BaseSession(object):
     __metaclass__ = ABCMeta
 
     def __init__(self, session=None, conn_timeout      = 10,
-                 read_timeout      = 10):
+                 read_timeout      = 10, verify_ssl       = True):
         self.conn_timeout = conn_timeout
         self.read_timeout = read_timeout
         self._session = session
+        self._ssl = verify_ssl
 
     @abstractproperty
     def session(self):
@@ -80,8 +81,10 @@ if not BUILD_GCLOUD_REST:
     class AioSession(BaseSession):
         @property
         def session(self)                         :
+            connector = aiohttp.TCPConnector(ssl=self._ssl)
             self._session = self._session or aiohttp.ClientSession(
-                conn_timeout=self.conn_timeout, read_timeout=self.read_timeout)
+                conn_timeout=self.conn_timeout, read_timeout=self.read_timeout,
+                connector=connector)
             return self._session
 
         def post(self, url     , headers                ,
@@ -143,6 +146,7 @@ if BUILD_GCLOUD_REST:
         @property
         def session(self)                    :
             self._session = self._session or requests.Session()
+            self._session.verify = self._ssl
             return self._session
 
         def post(self, url     , headers                , data      = None,
